Masquage — Documentation audiometry_trainer 0.1.16

# Masquage

Pour masquer l’oreille non testée (ONT) pendant l’audiométrie par conduction aérienne fixez le `Niveau du can. 2` à la valeur que vous souhaitez et assurez-vous que la case `Can. 2 ON` soit cochée.

Pour le masquage pendant l’audiométrie en conduction osseuse, en outre, assurez-vous que l” `État de l'oreille non testée` soit `Écouter sur l'oreille` (sinon le logiciel estime que le bruit est envoyé à l’écouter, mais que l’écouter n’est pas sur/dans l’oreille du sujet, par conséquent le bruit n’arrive pas à l’oreille du sujet). `audiometry_trainer` mets en automatique l” `État de l'oreille non testée` sur `Écouter sur l'oreille` quand vous cochez la case `Can. 2 ON`. Cette petite complication dans le masquage en conduction osseuse est due au fait que `audiometry_trainer` vous permet de tester le seuils par CO soit avec l’ONT nue, soit avec l’ONT couverte par l’écouter sans que l’écouter envoie du bruit. Cela est utile pour mesurer l’effet d’occlusion (voir Mesurer l’effet d’occlusion).

La case `Verrouiller les canaux` peut être utilisée pour « verrouiller » l’oreille testée (OT) et l’ONT de façon que des changements de niveau du signal envoyé à l’OT changent aussi le niveau du bruit envoyé à l’ONT.

## Atténuation interaurale

Le valeurs d’atténuation interaurale (AI) pour le casque supra-aural et pour l” écouter de type insert sont tirés de façon aléatoire d’une distribution uniforme. Les limites inférieure et supérieure et de cette distribution sont spécifiques à chaque fréquence et sont basés sur les valeurs publiés par [MunroAndAgnew1999]. Pour les fréquences qui n’ont pas été testées par [MunroAndAgnew1999] les valeurs d’un fréquence proche ont été utilisées. Les limites inférieure et supérieure de cette distribution en fonction de la fréquence sont affichées dans le tableau table-IA_supra pour le casque supra-aural et dans le tableau table-IA_insert pour l’écouter insert.

Tableau 1 Limites inférieure et supérieure de la distribution uniforme pour l’atténuation interaurale pour le casque supra-aural.
Fréq. | Inférieur | Supérieur
--- | --- | ---
125 Hz | 48 | 74
250 Hz | 48 | 74
500 Hz | 44 | 74
750 Hz | 44 | 74
1000 Hz | 48 | 72
1500 Hz | 48 | 72
2000 Hz | 44 | 74
3000 Hz | 56 | 82
4000 Hz | 50 | 82
6000 Hz | 44 | 82
8000 Hz | 42 | 80

Tableau 2 Limites inférieure et supérieure de la distribution uniforme pour l’atténuation interaurale pour l’écouter insert.
Fréq. | Inférieur | Supérieur
--- | --- | ---
125 Hz | 72 | 103
250 Hz | 72 | 103
500 Hz | 64 | 96
750 Hz | 64 | 96
1000 Hz | 58 | 86
1500 Hz | 58 | 86
2000 Hz | 56 | 82
3000 Hz | 58 | 96
4000 Hz | 72 | 98
6000 Hz | 54 | 96
8000 Hz | 62 | 82

Les valeurs d’AI pour la conduction osseuse (CO) sont tirées pour chaque cas d’une distribution uniforme. Les limites inférieure et supérieure de cette distribution en fonction de la fréquence sont affichées dans le tableau table-IA_bone. Ces valeurs sont basé sur l’observation que l’AI pour la stimulation en CO est essentiellement néante à 250 Hz et augmente jusqu’à environ 15 dB à 4000 Hz ([Studebaker1967]; [Gelfand2016]). Des données plus nuancées sur l’AI en CO ont été publiées [Stenfelt2012] et pourraient être intégrées à des versions futurs de `audiometry_trainer`.

Tableau 3 Limites inférieure et supérieure de la distribution uniforme pour l’atténuation interaurale en conduction osseuse.
Fréq. | Inférieur | Supérieur
--- | --- | ---
125 Hz | 0 | 0
250 Hz | 0 | 0
500 Hz | 0 | 2
750 Hz | 0 | 3
1000 Hz | 0 | 4
1500 Hz | 0 | 5
2000 Hz | 0 | 7
3000 Hz | 0 | 10
4000 Hz | 0 | 15
6000 Hz | 0 | 15
8000 Hz | 0 | 15

## Effet d’occlusion

Pour des cas sans perte de transmission la taille de l’effet d’occlusion (EO) est tirée de façon aléatoire pour chaque cas d’une distribution uniforme. Les limites inférieure et supérieure de cette distribution en fonction de la fréquence sont affichées dans le tableau table-OE_supra pour un casque supra-aural et dans le tableau table-OE_insert pour un écouter insert. Ces valeurs ont été choisies pour s’approcher à la gamme des valeurs publiées dans plusieurs études et résumées par [Gelfand2016].

Tableau 4 Limites inférieure et supérieure de la distribution uniforme pour l’l’effet d’occlusion pour casque supra-aural. Pour des fréquences > 1000 Hz l’effet d’occlusion est toujours néant.
Fréq. | Inférieur | Supérieur
--- | --- | ---
125 Hz | 15 | 30
125 Hz | 15 | 30
500 Hz | 8 | 26
750 Hz | 8 | 26
1000 Hz | 4 | 12

Tableau 5 Limites inférieure et supérieure de la distribution uniforme pour l’effet d’occlusion pour l’écouter insert. Pour des fréquences > 1000 Hz l’effet d’occlusion est toujours zéro.
Fréq. | Inférieur | Supérieur
--- | --- | ---
125 Hz | 2 | 10
125 Hz | 2 | 10
500 Hz | 2 | 10
750 Hz | 2 | 10
1000 Hz | 2 | 10

L’EO est absent en présence d’une perte de transmission/mixte avec un Rinne > 20 dB [MartinEtAl1974]. Pour cette raison, s’il y a un Rinne >= 20 dB l’EO est fixée à zéro. Pour un Rinne entre 0 et 10 dB la taille de l’OE est ajustée par rapport au Rinne avec l’équation suivante :

(1)\[OE_{out} = OE_{inp} - OE_{inp} (ABG/20)\]

où \(OE_{inp}\) est l’OE avant l’ajustement et \(OE_{out}\) est l’OE après l’ajustement. Cela implique que l’OE est réduit de façon progressive avec l’augmenter du Rinne, arrivant à zéro pour un Rinne de 20 dB.

L’EO affectera le niveau du signal qui arrive à l’ONT quand on masque pour le test en CO [Gelfand2016]. Une chose qui n’est pas souvent mentionnée est que l’EO, ou plus précisément la manque d’EO quand l’OT n’est pas couverte pendant le test en CO, affectera le calcul du niveau du bruit qui arrivera à l’OT. Les valeurs d’AI pour les casques/inserts utilisés pour envoyer le bruit masquant à l’ONT sont basés sur la supposition que les deux oreilles sont couvertes avec le casque/insert. Si cela n’est pas le cas pour une oreille, l’AI pour des sons qui arrivent à cette oreille est augmentée de la taille de l’EO ([Yacullo1997], [Turner2004]). Cela signifie que pour des sons graves, qui sont concernés par ces effets, tandis que l’EO augmente le niveau minimal du bruit masquant (car le niveau du signal est accru à l’ONT), cette augmentation est « compensée » d’une certaine façon par une augmentation parallèle du niveau maximal du bruit masquant (car l’AI pour le bruit sera plus grande).

### Mesurer l’effet d’occlusion

Certains auteurs (par ex. [Gelfand2016]) recommandent de mesurer l’EO pour chaque sujet pour fixer la valeur à utiliser dans les formules de masquage. Cela peut se faire en mesurant le seuil en CO pendant que le casque est placé sur l’ONT , mais sans que du bruit soit envoyé avec ce casque. Le seuil obtenu dans cette condition « avec casque » peut ensuite être comparé à celui obtenu avec l’ONT nue pour estimer la taille de l’EO [MartinEtAl1974]. Pour obtenir de seuils en CO avec l’ONT couverte par le casque, mais sans que ce dernier envoie du bruit, dans `audiometry_trainer` vous devez mettre l” `État de l'oreille non testée` sur l’option `Écouter sur l'oreille` et vous assurer que la case `Can. 2 ON` ne soit pas cochée. La taille de l’effet d’occlusion mesurée de cette façon dépendra du transducteur sélectionné pour le `Canal 2` (casque supra-aural ou écouter insert), donc assurez-vous d’avoir sélectionné le même transducteur que vous allez utiliser plus tard pour le masquage.

Une limitation de cette technique est que dans certains cas elle peut sous-estimer la taille de l’EO ([FagelsonAndMartin1994]; [Yacullo1997]). Cela peut arriver dans le cas d’un sujet avec un seuil en CO pour l’ONT qui est proche de la limite inférieure de la sortie de l’ossivibrateur. Par exemple, si le sujet a un seuil en CO proche de 0 dB HL et l’ossivibrateur a une limite de sortie inférieure de -20 dB HL, des EOs supérieurs à 20 dB seraient sous-estimés. Cela peut aussi arriver si le seuil en CO de l’OT est inférieur au seuil en CO de l’ONT. Par exemple, supposez que le seuil en CO de l’OT est de 20 dB HL, celui de l’ONT de 30 dB HL, et que l’EO de l’ONT est de 30 dB. Le seuil mesuré dans la condition oreille nue sera de 20 dB HL et lorsque le casque est placé sur l’ONT le seuil mesuré sera de 0 dB HL ; la différence entre les deux, l’estimation de l’EO, sera de 20 dB plutôt que du vrai EO de 30 dB. Si le masquage est utilisé juste pour confirmer que le seuil en CO non masqué est authentique, la sous-estimation de l’EO n’aura pas de conséquences ; l’OT avait le seuils le plus bas du départ, donc un sous-masquage confirmera simplement, « d’une façon incorrecte », la bonne décision que le seuil mesure venait de l’OT. Si l’EO estimé est utilisé pour une véritable recherche du seuil, le seuil masqué en CO de l’OT pourrait être plus bas que celui non-masqué car l’ONT sera souns-masquée.

## Masquage central

`audiometry_trainer` simule les effets de masquage central en augmentant le seuil de l’oreille testée quand le niveau du bruit masquant dans l’oreille non testée est audible au patient virtuel. La taille de cet effet de masquage central est tirée de façon aléatoire pour chaque sujet virtuel et chaque fréquence d’une distribution normale repliée avec une moyenne de zéro et une déviation standard de 3. Cela est basé sur l’observation que les effets de masquage central sont typiquement petits, de l’ordre de 5 dB [Yacullo1997].